# ptrcalc

Displays reverse zone for a given IPv6 or IPv4 Address.

```bash
~$ ptrcalc 42.43.123.43/29
IP Address: 42.43.123.43/29
    Reverse pointer:  43.123.43.42.in-addr.arpa
    Zone:             123.43.42.in-addr.arpa
    Host:             43

RFC2317:
    Reverse pointer:  43.40/29.123.43.42.in-addr.arpa
    Zone:             123.43.42.in-addr.arpa
    Host:             43

```

Supports RFC2317 and JSON output.
